@@ -1,6 +1,6 @@
 # GT4Py - GridTools Framework
 #
-# Copyright (c) 2014-2022, ETH Zurich
+# Copyright (c) 2014-2023, ETH Zurich
 # All rights reserved.
 #
 # This file is part of the GT4Py project and the GridTools framework.
@@ -21,4 +21,4 @@ definitions for the keywords of the DSL.
 import sys
 
 
-sys.modules["__externals__"] = sys.modules["gt4py.__externals__"]
+sys.modules["__externals__"] = sys.modules["gt4py.cartesian.__externals__"]
