@@ -1,6 +1,6 @@
 # GT4Py - GridTools Framework
 #
-# Copyright (c) 2014-2022, ETH Zurich
+# Copyright (c) 2014-2023, ETH Zurich
 # All rights reserved.
 #
 # This file is part of the GT4Py project and the GridTools framework.
@@ -14,3 +14,12 @@
 
 from . import gtscript_frontend
 from .base import REGISTRY, Frontend, from_name, register
+
+
+__all__ = [
+    "gtscript_frontend",
+    "REGISTRY",
+    "Frontend",
+    "from_name",
+    "register",
+]
