@@ -1,6 +1,6 @@
 # GT4Py - GridTools Framework
 #
-# Copyright (c) 2014-2022, ETH Zurich
+# Copyright (c) 2014-2023, ETH Zurich
 # All rights reserved.
 #
 # This file is part of the GT4Py project and the GridTools framework.
@@ -24,14 +24,10 @@ import numpy as np
 import pytest
 
 import gt4py.cartesian.gtc.utils as gtc_utils
-from gt4py import cartesian as gt
-from gt4py import cartesian as gt4pyc
-from gt4py import storage as gt_storage
-from gt4py.cartesian import gtscript
-from gt4py.cartesian import utils as gt_utils
-from gt4py.cartesian.definitions import AccessKind, Boundary, CartesianSpace, FieldInfo
-from gt4py.cartesian.frontend.nodes import Index
-from gt4py.cartesian.gtc.definitions import Shape
+from gt4py import cartesian as gt, cartesian as gt4pyc, storage as gt_storage
+from gt4py.cartesian import gtscript, utils as gt_utils
+from gt4py.cartesian.definitions import AccessKind, FieldInfo
+from gt4py.cartesian.gtc.definitions import Boundary, CartesianSpace, Index, Shape
 from gt4py.cartesian.stencil_object import StencilObject
 from gt4py.storage import utils as storage_utils
 
@@ -138,7 +134,6 @@ class SuiteMeta(type):
         cls_dict["origin"] = tuple(o[0] for o in max_boundary)
 
     def parametrize_generation_tests(cls_name, cls_dict):
-
         backends = cls_dict["backends"]
         dtypes = cls_dict["dtypes"]
         field_params = cls_dict["field_params"]
