@@ -1,6 +1,6 @@
 # GT4Py - GridTools Framework
 #
-# Copyright (c) 2014-2022, ETH Zurich
+# Copyright (c) 2014-2023, ETH Zurich
 # All rights reserved.
 #
 # This file is part of the GT4Py project and the GridTools framework.
@@ -506,7 +506,7 @@ class JinjaTemplate(BaseTemplate):
                 message += f" created at {self.definition_loc[0]}:{self.definition_loc[1]}"
                 try:
                     if hasattr(e, "lineno"):
-                        message += f" (error likely around line: {e.lineno})"  # type: ignore  # assume Jinja exception
+                        message += f" (error likely around line: {e.lineno})"
                 except Exception:
                     message = f"{message}:\n---\n{definition}\n---\n"
 
