@@ -1,6 +1,6 @@
 # GT4Py - GridTools Framework
 #
-# Copyright (c) 2014-2022, ETH Zurich
+# Copyright (c) 2014-2023, ETH Zurich
 # All rights reserved.
 #
 # This file is part of the GT4Py project and the GridTools framework.
@@ -35,12 +35,12 @@ from typing import *  # noqa: F403
 from typing import overload  # Only needed to avoid false flake8 errors
 
 import typing_extensions as _typing_extensions
-from typing_extensions import *  # type: ignore[misc]  # noqa: F403
+from typing_extensions import *  # type: ignore[assignment]  # noqa: F403
 
 
 if _sys.version_info >= (3, 9):
     # Standard library already supports PEP 585 (Type Hinting Generics In Standard Collections)
-    from builtins import (  # type: ignore[misc]  # isort:skip
+    from builtins import (  # type: ignore[assignment]  # isort:skip
         tuple as Tuple,
         list as List,
         dict as Dict,
