@@ -1,6 +1,6 @@
 # GT4Py - GridTools Framework
 #
-# Copyright (c) 2014-2022, ETH Zurich
+# Copyright (c) 2014-2023, ETH Zurich
 # All rights reserved.
 #
 # This file is part of the GT4Py project and the GridTools framework.
@@ -25,3 +25,18 @@ try:
     from .interface import dace_descriptor  # noqa: F401
 except ImportError:
     pass
+
+
+__all__ = [
+    "interface",
+    "layout",
+    "empty",
+    "from_array",
+    "full",
+    "ones",
+    "zeros" "from_name",
+    "register",
+]
+
+if "dace_descriptor" in globals():
+    __all__ += ["dace_descriptor"]
